##  Accessing Previous Versions
In the view mode, from the menu at the top right corner of the diagram, select Version History. This opens the version history panel on the right, where you can see details of updates, including who made changes, the date and time of modifications, and the version description provided by the author.
You can browse through different versions from the list and select any to open it in view mode. Note that only the current version can be edited by clicking Edit at the top of the diagram.
Also, note that when the version history panel is open, certain diagram functionalities—such as applying filters, applying views, or previewing fact sheet information in the side panel—are unavailable. Clicking on a fact sheet in the diagram or a linked diagram opens it in a new tab.
![Gif of steps for opening the version history for a diagram.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752138f7a441014adcdddb7b75588fc_LowRes.gif)
Accessing Previous Versions of the Diagram
